@@ -1,15 +1,21 @@
-"""An easy-to-use and lightweight API wrapper for Censys ASM (censys.io)."""
+"""An easy-to-use and lightweight API wrapper for Censys ASM (app.censys.io)."""
 from .assets import Assets, CertificatesAssets, DomainsAssets, HostsAssets
 from .client import AsmClient
 from .clouds import Clouds
 from .events import Events
+from .inventory import InventorySearch
+from .risks import Risks, Risksv1, Risksv2
 from .seeds import Seeds
 
 __all__ = [
     "AsmClient",
     "Clouds",
     "Events",
+    "Risks",
+    "Risksv1",
+    "Risksv2",
     "Seeds",
+    "InventorySearch",
     "Assets",
     "CertificatesAssets",
     "DomainsAssets",
