@@ -3,5 +3,12 @@ from .assets import Assets
 from .certificates import CertificatesAssets
 from .domains import DomainsAssets
 from .hosts import HostsAssets
+from .subdomains import SubdomainsAssets
 
-__all__ = ["Assets", "CertificatesAssets", "DomainsAssets", "HostsAssets"]
+__all__ = [
+    "Assets",
+    "CertificatesAssets",
+    "DomainsAssets",
+    "HostsAssets",
+    "SubdomainsAssets",
+]
