@@ -1,10 +1,11 @@
 """Interact with the Censys Seeds, Assets, and Logbook APIs."""
 from typing import Optional
 
-from .assets import CertificatesAssets, DomainsAssets, HostsAssets
+from .assets import CertificatesAssets, DomainsAssets, HostsAssets, SubdomainsAssets
 from .clouds import Clouds
 from .events import Events
-from .risks import Risks
+from .inventory import InventorySearch
+from .risks import Risksv2
 from .seeds import Seeds
 
 
@@ -24,4 +25,19 @@ class AsmClient:
         self.domains = DomainsAssets(api_key, **kwargs)
         self.events = Events(api_key, **kwargs)
         self.clouds = Clouds(api_key, **kwargs)
-        self.risks = Risks(api_key, **kwargs)
+        self.risks = Risksv2(api_key, **kwargs)
+        self.inventory = InventorySearch(api_key, **kwargs)
+
+        # Save the arguments for parameterized client usage
+        self.__api_kwargs = kwargs
+
+    def get_subdomains(self, domain: str):
+        """Get an API instance for subdomains of the parent domain.
+
+        Args:
+            domain: (str): Parent domain to access.
+
+        Returns:
+            SubdomainsAssets: A Subdomains Assets API instance .
+        """
+        return SubdomainsAssets(domain, self.domains._api_key, **self.__api_kwargs)
