@@ -4,20 +4,25 @@ import csv
 import datetime
 import json
 import os.path
-from typing import List, Optional
+import sys
+from typing import Any, Dict, List, Optional, Union
 
 from rich.console import Console
 
+from censys.common.config import DEFAULT, get_config
 from censys.common.deprecation import DeprecationDecorator
 
-Fields = List[str]
-Results = List[dict]
+Results = Union[List[dict], Dict[str, Any]]
 
-V1_INDEXES = ["ipv4", "certs", "websites"]
+V1_INDEXES = ["certs"]
 V2_INDEXES = ["hosts"]
 INDEXES = V1_INDEXES + V2_INDEXES
 
-console = Console()
+config = get_config()
+color = config.get(DEFAULT, "color")
+color_system = "auto" if color else None
+console = Console(color_system=color_system)  # type: ignore
+err_console = Console(color_system=color_system, file=sys.stderr)  # type: ignore
 
 
 def print_wrote_file(file_path: str):
@@ -31,13 +36,13 @@ def print_wrote_file(file_path: str):
 
 
 @DeprecationDecorator("CSV output is deprecated and will be removed in the future.")
-def _write_csv(file_path: str, search_results: Results, fields: Fields):
+def _write_csv(file_path: str, search_results: Results, fields: List[str]):
     """Write search results to a new file in CSV format.
 
     Args:
         file_path (str): Name of the file to write to on the disk.
         search_results (Results): A list of results from the query.
-        fields (Fields): A list of fields to write as headers.
+        fields (List[str]): A list of fields to write as headers.
     """
     with open(file_path, "w") as output_file:
         if search_results and isinstance(search_results, list):
@@ -66,21 +71,24 @@ def _write_json(file_path: str, search_results: Results):
     print_wrote_file(file_path)
 
 
-def _write_screen(search_results: Results):
+def _write_screen(search_results: Results):  # pragma: no cover
     """Writes search results to standard output.
 
     Args:
         search_results (Results): A list of results from the query.
     """
-    print(json.dumps(search_results, indent=4))
+    config = get_config()
+    if config.get(DEFAULT, "color"):
+        console.print_json(data=search_results)
+    else:
+        print(json.dumps(search_results, indent=4))
 
 
 def write_file(
     results_list: Results,
-    file_format: str = "screen",
+    file_format: Optional[str] = None,
     file_path: Optional[str] = None,
-    base_name: str = "censys-query-output",
-    csv_fields: Fields = [],
+    csv_fields: Optional[List[str]] = None,
 ):
     """Maps formats and writes results.
 
@@ -88,21 +96,19 @@ def write_file(
         results_list (Results): A list of results from the API query.
         file_format (str): Optional; The format of the output.
         file_path (str): Optional; A path to write results to.
-        base_name (str): Optional; The base name of the output file.
-        csv_fields (Fields): Optional; A list of fields to write to CSV.
+        csv_fields (List[str]): Optional; A list of fields to write to CSV.
     """
     if file_format and isinstance(file_format, str):
         file_format = file_format.lower()
 
     if not file_path:
-        # This method just creates some dynamic file names
-        file_path = ".".join([base_name, file_format])
-    elif file_path.endswith(".json"):
-        file_format = "json"
+        file_path = "temp-out.json"
 
     if file_format == "json":
         _write_json(file_path, results_list)
     elif file_format == "csv":
+        if csv_fields is None:  # pragma: no cover
+            csv_fields = []
         _write_csv(file_path, results_list, fields=csv_fields)
     else:
         _write_screen(results_list)
