@@ -3,7 +3,7 @@ import json
 import os
 import warnings
 from functools import wraps
-from typing import Any, Callable, List, Optional, Protocol, Type
+from typing import Any, Callable, Optional, Type
 
 import backoff
 import requests
@@ -13,13 +13,10 @@ from .exceptions import (
     CensysAPIException,
     CensysException,
     CensysJSONDecodeException,
-    CensysRateLimitExceededException,
     CensysTooManyRequestsException,
 )
 from .version import __version__
 
-Fields = Optional[List[str]]
-
 
 # Wrapper to make max_retries configurable at runtime
 def _backoff_wrapper(method: Callable):
@@ -28,34 +25,28 @@ def _backoff_wrapper(method: Callable):
         @backoff.on_exception(
             backoff.expo,
             (
-                CensysRateLimitExceededException,
                 CensysTooManyRequestsException,
                 requests.exceptions.Timeout,
             ),
             max_tries=self.max_retries,
-            max_time=30,
+            max_time=self.timeout,
         )
         def _impl():
-            return method(self, *args, *kwargs)
+            return method(self, *args, **kwargs)
 
         return _impl()
 
     return _wrapper
 
 
-class RequestsMethod(Protocol):  # noqa: D101
-    def __call__(self, path: str, **kwargs) -> requests.Response:  # noqa: D102
-        ...  # pragma: no cover
-
-
 class CensysAPIBase:
     """This is the base class for API queries."""
 
     DEFAULT_TIMEOUT: int = 30
     """Default API timeout."""
-    DEFAULT_USER_AGENT: str = f"censys/{__version__}"
+    DEFAULT_USER_AGENT: str = f"censys-python/{__version__}"
     """Default API user agent."""
-    DEFAULT_MAX_RETRIES: int = 10
+    DEFAULT_MAX_RETRIES: int = 5
     """Default max number of API retries."""
 
     def __init__(
@@ -131,10 +122,11 @@ class CensysAPIBase:
     @_backoff_wrapper
     def _make_call(
         self,
-        method: RequestsMethod,
+        method: Callable[..., Response],
         endpoint: str,
         args: Optional[dict] = None,
         data: Optional[Any] = None,
+        **kwargs,
     ) -> dict:
         """Make API call.
 
@@ -142,10 +134,11 @@ class CensysAPIBase:
         and decoding the responses.
 
         Args:
-            method (RequestsMethod): Method to send HTTP request.
+            method (Callable): Method to send HTTP request.
             endpoint (str): The path of API endpoint.
             args (dict): Optional; URL args that are mapped to params.
             data (Any): Optional; JSON data to serialize with request.
+            **kwargs: Arbitrary keyword arguments to pass to method.
 
         Raises:
             censys_exception: Exception Class for the Censys API.
@@ -162,6 +155,7 @@ class CensysAPIBase:
         request_kwargs = {
             "params": args or {},
             "timeout": self.timeout,
+            **kwargs,
         }
 
         if data:
@@ -169,7 +163,7 @@ class CensysAPIBase:
 
         res = method(url, **request_kwargs)
 
-        if res.status_code in range(200, 300):
+        if res.ok:
             # Check for a returned json body
             try:
                 json_data = res.json()
@@ -185,16 +179,13 @@ class CensysAPIBase:
         try:
             json_data = res.json()
             message = json_data.get("error") or json_data.get("message")
-            const = json_data.get("error_type") or json_data.get("status") or "unknown"
+            const = json_data.get("error_type") or json_data.get("status") or res.reason
             error_code = json_data.get("errorCode", "unknown")
             details = json_data.get("details", "unknown")
         except (ValueError, json.decoder.JSONDecodeError) as error:
-            message = (
-                f"Response from {res.url} is not valid JSON and cannot be decoded."
-            )
             raise CensysJSONDecodeException(
                 status_code=res.status_code,
-                message=message,
+                message=f"Response from {res.url} is not valid JSON and cannot be decoded.",
                 body=res.text,
                 const="badjson",
             ) from error
@@ -209,18 +200,35 @@ class CensysAPIBase:
             details=details,
         )
 
-    def _get(self, endpoint: str, args: Optional[dict] = None) -> dict:
-        return self._make_call(self._session.get, endpoint, args)
+    def _get(self, endpoint: str, args: Optional[dict] = None, **kwargs) -> dict:
+        return self._make_call(self._session.get, endpoint, args, **kwargs)
 
     def _post(
-        self, endpoint: str, args: Optional[dict] = None, data: Optional[dict] = None
+        self,
+        endpoint: str,
+        args: Optional[dict] = None,
+        data: Optional[dict] = None,
+        **kwargs,
     ) -> dict:
-        return self._make_call(self._session.post, endpoint, args, data)
+        return self._make_call(self._session.post, endpoint, args, data, **kwargs)
 
     def _put(
-        self, endpoint: str, args: Optional[dict] = None, data: Optional[dict] = None
+        self,
+        endpoint: str,
+        args: Optional[dict] = None,
+        data: Optional[dict] = None,
+        **kwargs,
     ) -> dict:
-        return self._make_call(self._session.put, endpoint, args, data)
+        return self._make_call(self._session.put, endpoint, args, data, **kwargs)
 
-    def _delete(self, endpoint: str, args: Optional[dict] = None) -> dict:
-        return self._make_call(self._session.delete, endpoint, args)
+    def _patch(
+        self,
+        endpoint: str,
+        args: Optional[dict] = None,
+        data: Optional[dict] = None,
+        **kwargs,
+    ) -> dict:
+        return self._make_call(self._session.patch, endpoint, args, data, **kwargs)
+
+    def _delete(self, endpoint: str, args: Optional[dict] = None, **kwargs) -> dict:
+        return self._make_call(self._session.delete, endpoint, args, **kwargs)
