@@ -1,6 +1,6 @@
 """Interact with all Search APIs."""
 from ..common.deprecation import DeprecationDecorator
-from .v1 import CensysCertificates, CensysData, CensysIPv4, CensysWebsites
+from .v1 import CensysCertificates, CensysData
 from .v2 import CensysCerts, CensysHosts
 
 
@@ -19,8 +19,6 @@ class SearchClient:
 
         >>> certs = c.v1.certificates # CensysCertificates()
         >>> data = c.v1.data # CensysData()
-        >>> ipv4 = c.v1.ipv4 # CensysIPv4()
-        >>> websites = c.v1.websites # CensysWebsites()
         >>> hosts = c.v2.hosts # CensysHosts()
         >>> certs = c.v2.certs # CensysCerts()
     """
@@ -32,24 +30,37 @@ class SearchClient:
             "The v1 Search API is deprecated and will be removed in the future."
         )
         def __init__(self, *args, **kwargs):
-            """Inits V1."""
+            """Inits V1.
+
+            Args:
+                *args: Variable length argument list.
+                **kwargs: Arbitrary keyword arguments.
+            """
             self.certificates = CensysCertificates(*args, **kwargs)
             # Alias certs to certificates
             self.certs = self.certificates
             self.data = CensysData(*args, **kwargs)
-            self.ipv4 = CensysIPv4(*args, **kwargs)
-            self.websites = CensysWebsites(*args, **kwargs)
 
     class _V2:
         """Class for v2 Search APIs."""
 
         def __init__(self, *args, **kwargs):
-            """Inits V2."""
+            """Inits V2.
+
+            Args:
+                *args: Variable length argument list.
+                **kwargs: Arbitrary keyword arguments.
+            """
             self.hosts = CensysHosts(*args, **kwargs)
             self.certs = CensysCerts(*args, **kwargs)
 
     def __init__(self, *args, **kwargs):
-        """Inits SearchClient."""
+        """Inits SearchClient.
+
+        Args:
+            *args: Variable length argument list.
+            **kwargs: Arbitrary keyword arguments.
+        """
         # Backwards compatability
         if len(args) == 2:
             kwargs["api_id"] = args[0]
