@@ -14,9 +14,6 @@ from censys.common.exceptions import (
 )
 from censys.common.types import Datetime
 from censys.common.utils import format_rfc3339
-from censys.search.v1.api import CensysSearchAPIv1
-
-Fields = Optional[List[str]]
 
 INDEX_TO_KEY = {"hosts": "ip"}
 
@@ -28,12 +25,10 @@ class CensysSearchAPIv2(CensysAPIBase):
         >>> c = CensysSearchAPIv2()
     """
 
-    DEFAULT_URL: str = "https://search.censys.io/api/v2"
+    DEFAULT_URL: str = "https://search.censys.io/api"
     """Default Search API base URL."""
     INDEX_NAME: str = ""
     """Name of Censys Index."""
-    v1: CensysSearchAPIv1
-    """Search V1 Endpoints on V2"""
 
     def __init__(
         self, api_id: Optional[str] = None, api_secret: Optional[str] = None, **kwargs
@@ -70,22 +65,12 @@ class CensysSearchAPIv2(CensysAPIBase):
         self._session.auth = (self._api_id, self._api_secret)
 
         # Generate concrete paths to be called
-        self.view_path = f"/{self.INDEX_NAME}/"
-        self.search_path = f"/{self.INDEX_NAME}/search"
-        self.aggregate_path = f"/{self.INDEX_NAME}/aggregate"
-        self.metadata_path = f"/metadata/{self.INDEX_NAME}"
-        self.tags_path = "/tags"
-
-        # Set up the v1 API
-        v1_kwargs = kwargs.copy()
-        v1_kwargs.update(
-            {
-                "url": "https://search.censys.io/api/v1",
-                "api_id": self._api_id,
-                "api_secret": self._api_secret,
-            }
-        )
-        self.v1 = CensysSearchAPIv1(**v1_kwargs)
+        self.view_path = f"/v2/{self.INDEX_NAME}/"
+        self.search_path = f"/v2/{self.INDEX_NAME}/search"
+        self.aggregate_path = f"/v2/{self.INDEX_NAME}/aggregate"
+        self.metadata_path = f"/v2/metadata/{self.INDEX_NAME}"
+        self.tags_path = "/v2/tags"
+        self.account_path = "/v1/account"
 
     def _get_exception_class(  # type: ignore
         self, res: Response
@@ -100,8 +85,7 @@ class CensysSearchAPIv2(CensysAPIBase):
         Returns:
             dict: Quota response.
         """
-        # Make account call to v1 endpoint
-        return self.v1.account()
+        return self._get(self.account_path)
 
     def quota(self) -> dict:
         """Returns metadata of a given search query.
@@ -125,6 +109,7 @@ class CensysSearchAPIv2(CensysAPIBase):
             per_page: Optional[int] = None,
             cursor: Optional[str] = None,
             pages: int = 1,
+            **kwargs: Any,
         ):
             """Inits Query.
 
@@ -133,7 +118,8 @@ class CensysSearchAPIv2(CensysAPIBase):
                 query (str): The query to be executed.
                 per_page (int): Optional; The number of results to be returned for each page. Defaults to 100.
                 cursor (int): Optional; The cursor of the desired result set.
-                pages (int): Optional; The number of pages returned. Defaults to 1.
+                pages (int): Optional; The number of pages returned. Defaults to 1. If you set this to -1, it will return all pages.
+                **kwargs (Any): Optional; Additional arguments to be passed to the query.
             """
             self.api = api
             self.query = query
@@ -145,6 +131,7 @@ class CensysSearchAPIv2(CensysAPIBase):
                 self.pages = float("inf")
             else:
                 self.pages = pages
+            self.extra_args = kwargs
 
         def __call__(self, per_page: Optional[int] = None) -> List[dict]:
             """Search current index.
@@ -161,12 +148,12 @@ class CensysSearchAPIv2(CensysAPIBase):
             if self.page > self.pages:
                 raise StopIteration
 
-            args = {
-                "q": self.query,
-                "per_page": per_page or self.per_page or 100,
-                "cursor": self.nextCursor or self.cursor,
-            }
-            payload = self.api._get(self.api.search_path, args)
+            payload = self.api.raw_search(
+                query=self.query,
+                per_page=per_page or self.per_page or 100,
+                cursor=self.nextCursor or self.cursor,
+                **self.extra_args,
+            )
             self.page += 1
             result = payload["result"]
             self.nextCursor = result["links"]["next"]
@@ -190,27 +177,35 @@ class CensysSearchAPIv2(CensysAPIBase):
             """
             return self
 
-        def view_all(self) -> Dict[str, dict]:
+        def view_all(self, max_workers: int = 20) -> Dict[str, dict]:
             """View each document returned from query.
 
             Please note that each result returned by the query will be looked up using the view method.
 
+            Args:
+                max_workers (int): The number of workers to use. Defaults to 20.
+
             Returns:
                 Dict[str, dict]: Dictionary mapping documents to that document's result set.
             """
-            threads = []
             results = {}
 
             document_key = INDEX_TO_KEY.get(self.api.INDEX_NAME, "ip")
 
-            with ThreadPoolExecutor(max_workers=20) as executor:
+            with ThreadPoolExecutor(max_workers) as executor:
+                threads = {}
                 for hit in self.__call__():
-                    document_id = hit[document_key]
-                    threads.append(executor.submit(self.api.view, document_id))
+                    hit_key = hit[document_key]
+                    if "name" in hit:
+                        hit_key += "+" + hit["name"]
+                    threads[executor.submit(self.api.view, hit_key)] = hit_key
 
                 for task in as_completed(threads):
-                    result = task.result()
-                    results[result[document_key]] = result
+                    document_id = threads[task]
+                    try:
+                        results[document_id] = task.result()
+                    except Exception as e:
+                        results[document_id] = {"error": str(e)}
 
             return results
 
@@ -220,6 +215,7 @@ class CensysSearchAPIv2(CensysAPIBase):
         per_page: Optional[int] = None,
         cursor: Optional[str] = None,
         pages: int = 1,
+        **kwargs: Any,
     ) -> Query:
         """Search current index.
 
@@ -231,11 +227,41 @@ class CensysSearchAPIv2(CensysAPIBase):
             per_page (int): Optional; The number of results to be returned for each page. Defaults to 100.
             cursor (int): Optional; The cursor of the desired result set.
             pages (int): Optional; The number of pages returned. Defaults to 1.
+            **kwargs (Any): Optional; Additional arguments to be passed to the query.
 
         Returns:
             Query: Query object that can be a callable or an iterable.
         """
-        return self.Query(self, query, per_page, cursor, pages)
+        return self.Query(self, query, per_page, cursor, pages, **kwargs)
+
+    def raw_search(
+        self,
+        query: str,
+        per_page: Optional[int] = None,
+        cursor: Optional[str] = None,
+        **kwargs: Any,
+    ) -> dict:
+        """Search current index.
+
+        Searches the given index for all records that match the given query.
+        This method does no automatic pagination or post processing.
+
+        Args:
+            query (str): The query to be executed.
+            per_page (int): Optional; The number of results to be returned for each page. Defaults to 100.
+            cursor (int): Optional; The cursor of the desired result set.
+            **kwargs (Any): Optional; Additional arguments to be passed to the query.
+
+        Returns:
+            dict: The raw result set.
+        """
+        args = {
+            "q": query,
+            "per_page": per_page or 100,
+            "cursor": cursor,
+            **kwargs,
+        }
+        return self._get(self.search_path, args)
 
     def view(
         self,
@@ -261,8 +287,47 @@ class CensysSearchAPIv2(CensysAPIBase):
 
         return self._get(self.view_path + document_id, args)["result"]
 
+    def bulk_view(
+        self,
+        document_ids: List[str],
+        at_time: Optional[Datetime] = None,
+        max_workers: int = 20,
+    ) -> Dict[str, dict]:
+        """Bulk view documents from current index.
+
+        View the current structured data we have on a list of documents.
+        For more details, see our documentation: https://search.censys.io/api
+
+        Args:
+            document_ids (List[str]): The IDs of the documents you are requesting.
+            at_time ([str, datetime.date, datetime.datetime]):
+                Optional; Fetches a document at a given point in time.
+            max_workers (int): The number of workers to use. Defaults to 20.
+
+        Returns:
+            Dict[str, dict]: Dictionary mapping document IDs to that document's result set.
+        """
+        if at_time:
+            at_time = format_rfc3339(at_time)
+
+        documents = {}
+        with ThreadPoolExecutor(max_workers) as executor:
+            threads = {
+                executor.submit(self.view, document_id, at_time): document_id
+                for document_id in document_ids
+            }
+
+            for task in as_completed(threads):
+                document_id = threads[task]
+                try:
+                    documents[document_id] = task.result()
+                except Exception as e:
+                    documents[document_id] = {"error": str(e)}
+
+        return documents
+
     def aggregate(
-        self, query: str, field: str, num_buckets: Optional[int] = None
+        self, query: str, field: str, num_buckets: Optional[int] = None, **kwargs: Any
     ) -> dict:
         """Aggregate current index.
 
@@ -273,11 +338,12 @@ class CensysSearchAPIv2(CensysAPIBase):
             query (str): The query to be executed.
             field (str): The field you are running a breakdown on.
             num_buckets (int): Optional; The maximum number of values. Defaults to 50.
+            **kwargs (Any): Optional; Additional arguments to be passed to the query.
 
         Returns:
             dict: The result set returned.
         """
-        args = {"q": query, "field": field, "num_buckets": num_buckets}
+        args = {"q": query, "field": field, "num_buckets": num_buckets, **kwargs}
         return self._get(self.aggregate_path, args)["result"]
 
     def metadata(self) -> dict:
@@ -317,6 +383,34 @@ class CensysSearchAPIv2(CensysAPIBase):
             self.view_path + document_id + "/comments", data={"contents": contents}
         )["result"]
 
+    def delete_comment(self, document_id: str, comment_id: str) -> dict:
+        """Delete comment from a document.
+
+        Args:
+            document_id (str): The ID of the document you are requesting.
+            comment_id (str): The ID of the comment you are requesting.
+
+        Returns:
+            dict: The result set returned.
+        """
+        return self._delete(self.view_path + document_id + "/comments/" + comment_id)
+
+    def update_comment(self, document_id: str, comment_id: str, contents: str) -> dict:
+        """Update comment from a document.
+
+        Args:
+            document_id (str): The ID of the document you are requesting.
+            comment_id (str): The ID of the comment you are requesting.
+            contents (str): The contents of the comment.
+
+        Returns:
+            dict: The result set returned.
+        """
+        return self._put(
+            self.view_path + document_id + "/comments/" + comment_id,
+            data={"contents": contents},
+        )
+
     # Tags
 
     def list_all_tags(self) -> List[dict]:
